Documentation
¶
Index ¶
- Constants
- func CreateNewSpellFile(newSpellInfo SpellData) (string, error)
- func DeleteSpellSpec(spellId string) error
- func FindSpell(spellName string) string
- func GetAllSpells() map[string]*SpellData
- func GetMemoryUsage() map[string]util.MemoryResult
- func LoadSpellFiles()
- func SaveSpellScript(spellId string, content string) error
- func SaveSpellSpec(spec *SpellData) error
- func Summon(sourceUserId int, sourceMobId int, details any) (bool, error)
- type SpellData
- type SpellSchool
- type SpellType
Constants ¶
const ( WaitRoundsDefault = 3 Neutral SpellType = "neutral" // Neutral, no expected actor target, use on HarmSingle SpellType = "harmsingle" // Harmful, defaults to current aggro - magic missile etc HarmMulti SpellType = "harmmulti" // Harmful, defaults to all aggro mobs - chain lightning etc HelpSingle SpellType = "helpsingle" // Helpful, defaults on self - heal etc HelpMulti SpellType = "helpmulti" // Helpful, defaults on party - mass heal etc HarmArea SpellType = "harmarea" // Hits everyone in the room, even if hidden or friendly HelpArea SpellType = "helparea" // Hits everyone in the room, even if hidden SchoolRestoration SpellSchool = "restoration" // Healing, curing conditions, etc. SchoolIllusion SpellSchool = "illusion" // Light, darkness, invisibility, blink, etc. SchoolConjuration SpellSchool = "conjuration" // Summoning, teleportation, etc. )
Variables ¶
This section is empty.
Functions ¶
func CreateNewSpellFile ¶
func DeleteSpellSpec ¶ added in v0.9.8
func GetAllSpells ¶
func GetMemoryUsage ¶ added in v0.9.8
func GetMemoryUsage() map[string]util.MemoryResult
func LoadSpellFiles ¶
func LoadSpellFiles()
func SaveSpellScript ¶ added in v0.9.8
func SaveSpellSpec ¶ added in v0.9.8
Types ¶
type SpellData ¶
type SpellData struct {
SpellId string `yaml:"spellid,omitempty"`
Name string `yaml:"name,omitempty"`
Description string `yaml:"description,omitempty"`
Type SpellType `yaml:"type,omitempty"`
School SpellSchool `yaml:"school,omitempty"`
Cost int `yaml:"cost,omitempty"`
WaitRounds int `yaml:"waitrounds,omitempty"`
Difficulty int `yaml:"difficulty,omitempty"` // Augments final success chance by this %
}
func FindSpellByName ¶
func (*SpellData) GetDifficulty ¶
func (*SpellData) GetScriptPath ¶
type SpellSchool ¶
type SpellSchool string
Click to show internal directories.
Click to hide internal directories.