storage

package
v0.9.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 4, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type StorageData

type StorageData struct {
	Items []items.Item `yaml:"items,omitempty"`
}

StorageData holds the items stored for a single user.

type StorageModule

type StorageModule struct {
	// contains filtered or unexported fields
}

StorageModule owns all storage state.

func (*StorageModule) AddStorageItem

func (m *StorageModule) AddStorageItem(userId int, itm items.Item) bool

AddStorageItem is exported for cross-module use.

func (*StorageModule) GetStorageItems

func (m *StorageModule) GetStorageItems(userId int) []items.Item

GetStorageItems is exported for use by other systems (e.g. autocomplete).

func (*StorageModule) RemoveStorageItem

func (m *StorageModule) RemoveStorageItem(userId int, itm items.Item) bool

RemoveStorageItem is exported for cross-module use.

Jump to