Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StorageData ¶
StorageData holds the items stored for a single user.
type StorageModule ¶
type StorageModule struct {
// contains filtered or unexported fields
}
StorageModule owns all storage state.
func (*StorageModule) AddStorageItem ¶
func (m *StorageModule) AddStorageItem(userId int, itm items.Item) bool
AddStorageItem is exported for cross-module use.
func (*StorageModule) GetStorageItems ¶
func (m *StorageModule) GetStorageItems(userId int) []items.Item
GetStorageItems is exported for use by other systems (e.g. autocomplete).
func (*StorageModule) RemoveStorageItem ¶
func (m *StorageModule) RemoveStorageItem(userId int, itm items.Item) bool
RemoveStorageItem is exported for cross-module use.
Click to show internal directories.
Click to hide internal directories.